@@ -1,4 +1,3 @@
-# pylint: disable=arguments-differ,redefined-outer-name,redefined-builtin,too-many-locals,unused-import
 """
 Main interface for cloudsearchdomain service client
 
@@ -14,7 +13,7 @@ Usage::
 import sys
 from typing import IO, Any, Dict, Type, Union
 
-from botocore.exceptions import ClientError as Boto3ClientError
+from botocore.client import ClientMeta
 
 from mypy_boto3_cloudsearchdomain.type_defs import (
     SearchResponseTypeDef,
@@ -31,22 +30,31 @@ else:
 __all__ = ("CloudSearchDomainClient",)
 
 
+class BotocoreClientError(BaseException):
+    MSG_TEMPLATE: str
+
+    def __init__(self, error_response: Dict[str, Any], operation_name: str) -> None:
+        self.response: Dict[str, Any]
+        self.operation_name: str
+
+
 class Exceptions:
-    ClientError: Type[Boto3ClientError]
-    DocumentServiceException: Type[Boto3ClientError]
-    SearchException: Type[Boto3ClientError]
+    ClientError: Type[BotocoreClientError]
+    DocumentServiceException: Type[BotocoreClientError]
+    SearchException: Type[BotocoreClientError]
 
 
 class CloudSearchDomainClient:
     """
-    [CloudSearchDomain.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client)
+    [CloudSearchDomain.Client documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client)
     """
 
+    meta: ClientMeta
     exceptions: Exceptions
 
     def can_paginate(self, operation_name: str) -> bool:
         """
-        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.can_paginate)
+        [Client.can_paginate documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.can_paginate)
         """
 
     def generate_presigned_url(
@@ -57,7 +65,7 @@ class CloudSearchDomainClient:
         HttpMethod: str = None,
     ) -> str:
         """
-        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.generate_presigned_url)
+        [Client.generate_presigned_url documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.generate_presigned_url)
         """
 
     def search(
@@ -78,12 +86,12 @@ class CloudSearchDomainClient:
         stats: str = None,
     ) -> SearchResponseTypeDef:
         """
-        [Client.search documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.search)
+        [Client.search documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.search)
         """
 
     def suggest(self, query: str, suggester: str, size: int = None) -> SuggestResponseTypeDef:
         """
-        [Client.suggest documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.suggest)
+        [Client.suggest documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.suggest)
         """
 
     def upload_documents(
@@ -92,5 +100,5 @@ class CloudSearchDomainClient:
         contentType: Literal["application/json", "application/xml"],
     ) -> UploadDocumentsResponseTypeDef:
         """
-        [Client.upload_documents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.14.49/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.upload_documents)
+        [Client.upload_documents documentation](https://boto3.amazonaws.com/v1/documentation/api/1.16.28/reference/services/cloudsearchdomain.html#CloudSearchDomain.Client.upload_documents)
         """
